[![Build Status](https://img.shields.io/endpoint.svg?url=https%3A%2F%2Factions-badge.atrox.dev%2Farn4%2FLabTools%2Fbadge%3Fref%3Dmaster&style=popout)](https://actions-badge.atrox.dev/arn4/LabTools/goto?ref=master)
[![codecov](https://codecov.io/gh/arn4/LabTools/branch/master/graph/badge.svg)](https://codecov.io/gh/arn4/LabTools)


# LabTools
This is a Python Package written during the physics laboratory courses that I have
attended at the University of Pisa.

It can be used for fitting data, make plots, formatting data for LaTex
documents and generating tables. It is fully compatible with the uncertainties package.


## Installation
The easiest way to install LabTools is using `pip`:

```pip install labtools-arna```

If you don't like pip you can just clone the repository and use the code directly.

## Usage
To use the packcage just type:

```import LabTools```
[explain better!]

## Documentations
Unfortunately, there isn't structured documentation yet. There are many examples of usage in the repository I used for the Laboratory 3 Course at UniPi. You can find the source code at https://gitlab.com/l.arnaboldi/laboratorio-3.

If you would like to use this package and you have questions, feel free to write me an email (luca@arnaboldi.lu). I will be happy to help you with using LabTools!

## What are lab2 and lab1 verions?
In the folders `lab1` and  `lab2` there are old files I used in the lab before LabTools. All their functionalities have been reimplemented in LabTools, I keep them only for historical reasons.
